@@ -42,6 +42,9 @@ constant_numbers = {
     'CC_HAZARDOUS'    : 8,
     'CC_COVERED'      : 9,
     'CC_OVERSIZED'    : 10,
+    'CC_POWDERIZED'   : 11,
+    'CC_NON_POURABLE' : 12,
+    'CC_NEO_BULK'     : 12,
     'CC_SPECIAL'      : 15,
     'NO_CARGO_CLASS'           : 0,
     'ALL_NORMAL_CARGO_CLASSES' : 0x07FF,
